@@ -16,8 +16,6 @@
 import os
 import ast
 import yaml
-import pandas
-
 
 def move(file, newdir):
 
@@ -42,8 +40,9 @@ def listfiles(dir = ".", type = "", keepdir = False, keepext = True,
     """
     Returns a list of (nested) files or directories
 
-    filedir: str; default="."
-    filetype: str or tuple of strings; default=""
+    dir: str; default="."
+        Directory that should be checked
+    type: str or tuple of strings; default=""
         Filetype for the files to be listed. If filetype is dir, it will return
     keepdir: bool; default=False
         If the original directory should be kept as part of the filename
@@ -72,7 +71,7 @@ def listfiles(dir = ".", type = "", keepdir = False, keepext = True,
             outlist = [i for i in outlist if not i.startswith('.')]
 
         if keepdir:
-            outlist = [filedir + "/" + i  for i in outlist]
+            outlist = [dir + "/" + i  for i in outlist]
 
     outlist = sorted(outlist)
 
@@ -192,6 +191,7 @@ def loadyml(filename, value = None, add = True):
 def loadh5data(filename, dataset = "data"):
 
     import h5py
+    import pandas
     h5file = h5py.File(filename, 'r')
     dataset = pandas.DataFrame(h5file[dataset][:])
     h5file.close()
